@@ -19,24 +19,33 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 
-/* $Id: common.c,v 1.2 2005/04/11 18:02:57 evertonm Exp $ */
+/* $Id: common.c,v 1.4 2005/04/19 03:40:33 evertonm Exp $ */
 
 #include <stdio.h>
 #include <assert.h>
 
 #include "common.h"
 
+
+const char * const NEPIM_LABEL_PARTIAL      = "part";
+const char * const NEPIM_LABEL_TOTAL        = "sum";
+const char * const NEPIM_LABEL_TOTAL_BROKEN = "sum(broken)";
+
+
 const char *nepim_version()
 {
-  return "0.4";
+  return "0.5";
 }
 
 void nepim_dump_stat(FILE *out, const char *label, int sd, 
 		     long long bytes_recv, long long bytes_sent, 
-		     float interval, long sec_start, long sec_duration)
+		     float interval, long sec_start, 
+		     long sec_duration, int reads, int writes)
 {
   float kbps_recv = bytes_recv / (interval * 125); /* 8/1000 = 1/125 */
   float kbps_sent = bytes_sent / (interval * 125); /* 8/1000 = 1/125 */
+  float read_rate = reads / (interval * 1000);
+  float write_rate = writes / (interval * 1000);
   struct timeval now;
   int result;
       
@@ -44,13 +53,15 @@ void nepim_dump_stat(FILE *out, const char *label, int sd,
   assert(!result);
 
   fprintf(out,
-	  "%d: %s %ld/%ld kbps_recv=%.2f kbps_sent=%.2f\n", 
+	  "%d: %s %ld/%ld kbps_in=%.2f kbps_out=%.2f rcv/s=%.4f snd/s=%.4f\n", 
 	  sd,
 	  label,
 	  now.tv_sec - sec_start,
 	  sec_duration,
 	  kbps_recv,
-	  kbps_sent);
+	  kbps_sent,
+	  read_rate,
+	  write_rate);
 }
 
 void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe)
@@ -70,11 +81,13 @@ void report_broken_pipe_stat(FILE *out, const nepim_pipe_t *pipe)
   elapsed = elapsed_sec + elapsed_usec / 1000000;
 
   nepim_dump_stat(out, 
-		  "total(broken)",
+		  NEPIM_LABEL_TOTAL_BROKEN,
 		  pipe->sd, 
 		  pipe->byte_total_recv,
 		  pipe->byte_total_sent,
 		  elapsed, 
 		  pipe->tv_start.tv_sec,
-		  pipe->test_duration);
+		  pipe->test_duration,
+		  pipe->total_reads,
+		  pipe->total_writes);
 }
